<?

// Setup output array
$output = array();

// Uptime
// - CPU
exec("uptime |awk -F'average:' '{ print $2}'",$output);
$cpuusage = $output[0]*10;
?>
CPU load: [<?=round(trim(substr($cpuusage,0,5)));?>]

