<?
$host = "mysql5.wadns.net";
$user = "admin";
$password = "Pleskfire99";
$database = "mysql";
mysql_connect($host,$user,$password);

@mysql_select_db($database) or die( "Unable to select database");

$query = "SELECT * FROM users";
mysql_query($query);
mysql_close();

echo "MYSQL5 Working";
?>

