<?

// Setup output array
$output = array();

// Run mail queue
//exec("/usr/local/sbin/queue-monitor",$output);
exec("/var/qmail/bin/qmail-qstat",$output);

$line = $output[0];

	if(trim($line) != "") {
		$line = str_replace(": ", ": [", $line);
		$line .= "]";
		echo trim($line) . "<br />";
	}


?>
