<?

// Setup output array
$output = array();

// Run mail queue
exec("df -h",$output);


echo "\n<p style=\"font-family: monospace;\"><table>";
$count = 0;
foreach($output as $line)
{
	$cols = split(" ",$line);
	echo "\n\t<tr>";
	$styles = ""; $stylee = ""; if($count == 0) { $styles = "<b>"; $stylee = "</b>"; }
	foreach($cols as $c) { if(trim($c) != "") echo "\n\t\t<td>".$styles.$c.$styleb."</td>"; }
	echo "\n\t</tr>";
	$count++;
}
echo "\n</table></p>";
?>
